@@ -6,6 +6,7 @@ use crate::Height;
 use flex_error::define_error;
 
 define_error! {
+    #[derive(Debug, PartialEq, Eq)]
     Error {
         Ics02Client
             [ client_error::Error ]
@@ -29,13 +30,6 @@ define_error! {
                     e.connection_id)
             },
 
-        UninitializedConnection
-            { connection_id: ConnectionId }
-            | e | {
-                format_args!("connection end for identifier {0} was never initialized",
-                    e.connection_id)
-            },
-
         InvalidConsensusHeight
             {
                 target_height: Height,
@@ -119,13 +113,6 @@ define_error! {
         MissingCounterpartyPrefix
             | _ | { "missing counterparty prefix" },
 
-        MissingClient
-            { client_id: ClientId }
-            | e | {
-                format_args!("the client id does not match any client state: {0}",
-                    e.client_id)
-            },
-
         NullClientProof
             | _ | { "client proof must be present" },
 
@@ -139,16 +126,6 @@ define_error! {
         ConnectionVerificationFailure
             | _ | { "the connection proof verification failed" },
 
-        MissingClientConsensusState
-            {
-                height: Height,
-                client_id: ClientId,
-            }
-            | e | {
-                format_args!("the consensus state at height {0} for client id {1} could not be retrieved",
-                    e.height, e.client_id)
-            },
-
         MissingLocalConsensusState
             { height: Height }
             | e | { format_args!("the local consensus state could not be retrieved for height {}", e.height) },
@@ -171,5 +148,8 @@ define_error! {
                 format_args!("the client state proof verification failed for client id {0}",
                     e.client_id)
             },
+
+        ImplementationSpecific
+            | _ | { "implementation specific error" },
     }
 }
