@@ -9,6 +9,7 @@ use crate::ics03_connection::events::Attributes;
 use crate::ics03_connection::handler::verify::{check_client_consensus_height, verify_proofs};
 use crate::ics03_connection::handler::{ConnectionIdState, ConnectionResult};
 use crate::ics03_connection::msgs::conn_open_ack::MsgConnectionOpenAck;
+use crate::prelude::*;
 
 pub(crate) fn process(
     ctx: &dyn ConnectionReader,
@@ -84,8 +85,9 @@ pub(crate) fn process(
 
 #[cfg(test)]
 mod tests {
-    use std::convert::TryFrom;
-    use std::str::FromStr;
+    use crate::prelude::*;
+    use core::convert::TryFrom;
+    use core::str::FromStr;
     use test_env_log::test;
 
     use crate::events::IbcEvent;
@@ -154,7 +156,7 @@ mod tests {
         conn_end_prefix.set_counterparty(Counterparty::new(
             client_id.clone(),
             Some(msg_ack.counterparty_connection_id().clone()),
-            CommitmentPrefix::from(vec![]), // incorrect field
+            CommitmentPrefix::from(Vec::new()), // incorrect field
         ));
 
         let tests: Vec<Test> = vec![
