@@ -16,9 +16,7 @@ pub(crate) fn process(
     let mut output = HandlerOutput::builder();
 
     // Unwrap the old channel end and validate it against the message.
-    let mut channel_end = ctx
-        .channel_end(&(msg.port_id().clone(), msg.channel_id().clone()))
-        .ok_or_else(|| Error::channel_not_found(msg.port_id.clone(), msg.channel_id().clone()))?;
+    let mut channel_end = ctx.channel_end(&(msg.port_id().clone(), msg.channel_id().clone()))?;
 
     // Validate that the channel end is in a state where it can be closed.
     if channel_end.state_matches(&State::Closed) {
@@ -39,9 +37,7 @@ pub(crate) fn process(
         ));
     }
 
-    let conn = ctx
-        .connection_end(&channel_end.connection_hops()[0])
-        .ok_or_else(|| Error::missing_connection(channel_end.connection_hops()[0].clone()))?;
+    let conn = ctx.connection_end(&channel_end.connection_hops()[0])?;
 
     if !conn.state_matches(&ConnectionState::Open) {
         return Err(Error::connection_not_open(
