@@ -1,4 +1,5 @@
-use std::convert::TryFrom;
+use crate::prelude::*;
+use core::convert::TryFrom;
 
 use tendermint_proto::Protobuf;
 
@@ -100,6 +101,7 @@ impl From<MsgChannelCloseConfirm> for RawMsgChannelCloseConfirm {
 
 #[cfg(test)]
 pub mod test_util {
+    use crate::prelude::*;
     use ibc_proto::ibc::core::channel::v1::MsgChannelCloseConfirm as RawMsgChannelCloseConfirm;
     use ibc_proto::ibc::core::client::v1::Height;
 
@@ -123,7 +125,8 @@ pub mod test_util {
 
 #[cfg(test)]
 mod tests {
-    use std::convert::TryFrom;
+    use crate::prelude::*;
+    use core::convert::TryFrom;
 
     use ibc_proto::ibc::core::channel::v1::MsgChannelCloseConfirm as RawMsgChannelCloseConfirm;
     use ibc_proto::ibc::core::client::v1::Height;
