@@ -1,3 +1,5 @@
+use tendermint::abci::transaction::Hash;
+
 use crate::ics02_client::client_consensus::QueryClientEventRequest;
 use crate::ics04_channel::channel::QueryPacketEventDataRequest;
 
@@ -6,4 +8,8 @@ use crate::ics04_channel::channel::QueryPacketEventDataRequest;
 pub enum QueryTxRequest {
     Packet(QueryPacketEventDataRequest),
     Client(QueryClientEventRequest),
+    Transaction(QueryTxHash),
 }
+
+#[derive(Clone, Debug)]
+pub struct QueryTxHash(pub Hash);
